@@ -1,5 +1,5 @@
 /* RFC1524 (mailcap file) implementation */
-/* $Id: mailcap.c,v 1.78 2004/01/04 17:53:37 jonas Exp $ */
+/* $Id: mailcap.c,v 1.87.2.4 2005/05/01 22:03:23 jonas Exp $ */
 
 /* This file contains various functions for implementing a fair subset of
  * rfc1524.
@@ -20,8 +20,6 @@
 #include "config.h"
 #endif
 
-#ifdef CONFIG_MAILCAP
-
 #include <ctype.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -100,8 +98,7 @@ static struct option_info mailcap_options[] = {
 	INIT_OPT_STRING("mime.mailcap", N_("Path"),
 		"path", 0, DEFAULT_MAILCAP_PATH,
 		N_("Mailcap search path. Colon-separated list of files.\n"
-		"Leave as \"\" to use MAILCAP environment variable or\n"
-		"built-in defaults instead.")),
+		"Leave as \"\" to use MAILCAP environment variable instead.")),
 
 	INIT_OPT_BOOL("mime.mailcap", N_("Ask before opening"),
 		"ask", 0, 1,
@@ -109,11 +106,11 @@ static struct option_info mailcap_options[] = {
 
 	INIT_OPT_INT("mime.mailcap", N_("Type query string"),
 		"description", 0, 0, 2, 0,
-		N_("Type of description to show in \"what shall I do with this file\"\n"
+		N_("Type of description to show in \"what to do with this file\"\n"
 		"query dialog:\n"
-		"0 is show \"mailcap\".\n"
-		"1 is show program to be run.\n"
-		"2 is show mailcap description field if any; \"mailcap\" otherwise.")),
+		"0 is show \"mailcap\"\n"
+		"1 is show program to be run\n"
+		"2 is show mailcap description field if any; \"mailcap\" otherwise")),
 
 	INIT_OPT_BOOL("mime.mailcap", N_("Prioritize entries by file"),
 		"prioritize", 0, 1,
@@ -121,41 +118,6 @@ static struct option_info mailcap_options[] = {
 		"path. This means that wildcard entries (like: image/*) will\n"
 		"also be checked before deciding the handler.")),
 
-
-	/* Start of mailcap compatibility aliases:
-	 * Added: 2003-05-07, 0.5pre0.CVS.
-	 * Estimated due time: ? */
-	INIT_OPT_TREE("protocol", N_("Mailcap"),
-		"mailcap", 0,
-		N_("Options for mailcap support. (Deprecated. Please use\n"
-		"mime.mailcap instead)")),
-
-	INIT_OPT_ALIAS("protocol.mailcap", NULL,
-		"enable", 0, "mime.mailcap.enable",
-		N_("This option is deprecated and will be removed very soon.\n"
-		"Please use the mime.mailcap.enable option instead.")),
-
-	INIT_OPT_ALIAS("protocol.mailcap", NULL,
-		"path", 0, "mime.mailcap.path",
-		N_("This option is deprecated and will be removed very soon.\n"
-		"Please use the mime.mailcap.path option instead.")),
-
-	INIT_OPT_ALIAS("protocol.mailcap", NULL,
-		"ask", 0, "mime.mailcap.ask",
-		N_("This option is deprecated and will be removed very soon.\n"
-		"Please use the mime.mailcap.ask option instead.")),
-
-	INIT_OPT_ALIAS("protocol.mailcap", NULL,
-		"description", 0, "mime.mailcap.description",
-		N_("This option is deprecated and will be removed very soon.\n"
-		"Please use mime.mailcap.description option instead.")),
-
-	INIT_OPT_ALIAS("protocol.mailcap", NULL,
-		"prioritize", 0, "mime.mailcap.prioritize",
-		N_("This option is deprecated and will be removed very soon.\n"
-		"Please use the mime.mailcap.prioritize option instead.")),
-
-
 	NULL_OPTION_INFO,
 };
 
@@ -176,8 +138,8 @@ static inline void
 done_mailcap_entry(struct mailcap_entry *entry)
 {
 	if (!entry) return;
-	if (entry->testcommand)	mem_free(entry->testcommand);
-	if (entry->description)	mem_free(entry->description);
+	mem_free_if(entry->testcommand);
+	mem_free_if(entry->description);
 	mem_free(entry);
 }
 
@@ -190,7 +152,7 @@ init_mailcap_entry(unsigned char *command, int priority)
 	struct mailcap_entry *entry;
 	int commandlen = strlen(command);
 
-	entry = mem_calloc(1, sizeof(struct mailcap_entry) + commandlen);
+	entry = mem_calloc(1, sizeof(*entry) + commandlen);
 	if (!entry) return NULL;
 
 	memcpy(entry->command, command, commandlen);
@@ -210,7 +172,7 @@ add_mailcap_entry(struct mailcap_entry *entry, unsigned char *type, int typelen)
 	/* First check if the type is already checked in */
 	item = get_hash_item(mailcap_map, type, typelen);
 	if (!item) {
-		mitem = mem_alloc(sizeof(struct mailcap_hash_item) + typelen);
+		mitem = mem_alloc(sizeof(*mitem) + typelen);
 		if (!mitem) {
 			done_mailcap_entry(entry);
 			return;
@@ -262,7 +224,7 @@ get_mailcap_field(unsigned char **next)
 	if (!next || !*next) return NULL;
 
 	field = *next;
-	skip_whitespace(field);
+	skip_space(field);
 	fieldend = field;
 
 	/* End field at the next occurence of ';' but not escaped '\;' */
@@ -279,7 +241,7 @@ get_mailcap_field(unsigned char **next)
 		*next = fieldend;
 		fieldend--;
 		(*next)++;
-		skip_whitespace(*next);
+		skip_space(*next);
 	} else {
 		*next = NULL;
 		fieldend = field + strlen(field) - 1;
@@ -300,11 +262,11 @@ get_mailcap_field(unsigned char **next)
 static unsigned char *
 get_mailcap_field_text(unsigned char *field)
 {
-	skip_whitespace(field);
+	skip_space(field);
 
 	if (*field == '=') {
 		field++;
-		skip_whitespace(field);
+		skip_space(field);
 
 		return stracpy(field);
 	}
@@ -312,8 +274,6 @@ get_mailcap_field_text(unsigned char *field)
 	return NULL;
 }
 
-#undef skip_whitespace
-
 /* Parse optional extra definitions. Zero return value means syntax error  */
 static inline int
 parse_optional_fields(struct mailcap_entry *entry, unsigned char *line)
@@ -356,7 +316,7 @@ parse_optional_fields(struct mailcap_entry *entry, unsigned char *line)
 static void
 parse_mailcap_file(unsigned char *filename, unsigned int priority)
 {
-	FILE *file = fopen(filename, "r");
+	FILE *file = fopen(filename, "rb");
 	unsigned char *line = NULL;
 	size_t linelen = MAX_STR_LEN;
 	int lineno = 1;
@@ -389,8 +349,9 @@ parse_mailcap_file(unsigned char *filename, unsigned int priority)
 
 		if (!parse_optional_fields(entry, linepos)) {
 			done_mailcap_entry(entry);
-			ERROR("Bad formated entry for type %s in \"%s\" line %d",
-			      type, filename, lineno);
+			usrerror(gettext("Badly formated mailcap entry "
+			         "for type %s in \"%s\" line %d"),
+			         type, filename, lineno);
 			continue;
 		}
 
@@ -417,7 +378,7 @@ parse_mailcap_file(unsigned char *filename, unsigned int priority)
 	}
 
 	fclose(file);
-	if (line) mem_free(line); /* Alloced by file_read_line() */
+	mem_free_if(line); /* Alloced by file_read_line() */
 }
 
 
@@ -505,7 +466,7 @@ init_mailcap(struct module *module)
 
 	register_change_hooks(mimetypes_change_hooks);
 
-	if (get_opt_bool_tree(cmdline_options, "anonymous"))
+	if (get_cmd_opt_bool("anonymous"))
 		get_mailcap_enable() = 0;
 }
 
@@ -713,5 +674,3 @@ struct module mailcap_mime_module = struct_module(
 	/* init: */		init_mailcap,
 	/* done: */		done_mailcap
 );
-
-#endif /* CONFIG_MAILCAP */
